@@ -9,3 +9,7 @@ such as balance sheets or price lists.
 """
 
 from .version import __version__
+from .cli import cli
+from .aws_extract_tables import aws_extract_tables
+from .aws_setup import install_aws
+from .aws_setup import uninstall_aws
